/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface BeyondcorpSecurityGatewayApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-settable Application resource ID.
    * * Must start with a letter.
    * * Must contain between 4-63 characters from '/a-z-/'.
    * * Must end with a number or letter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#application_id BeyondcorpSecurityGatewayApplication#application_id}
    */
    readonly applicationId: string;
    /**
    * Optional. An arbitrary user-provided name for the Application resource.
    * Cannot exceed 64 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#display_name BeyondcorpSecurityGatewayApplication#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#id BeyondcorpSecurityGatewayApplication#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#project BeyondcorpSecurityGatewayApplication#project}
    */
    readonly project?: string;
    /**
    * ID of the Security Gateway resource this belongs to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#security_gateway_id BeyondcorpSecurityGatewayApplication#security_gateway_id}
    */
    readonly securityGatewayId: string;
    /**
    * endpoint_matchers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#endpoint_matchers BeyondcorpSecurityGatewayApplication#endpoint_matchers}
    */
    readonly endpointMatchers: BeyondcorpSecurityGatewayApplicationEndpointMatchers[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#timeouts BeyondcorpSecurityGatewayApplication#timeouts}
    */
    readonly timeouts?: BeyondcorpSecurityGatewayApplicationTimeouts;
    /**
    * upstreams block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#upstreams BeyondcorpSecurityGatewayApplication#upstreams}
    */
    readonly upstreams?: BeyondcorpSecurityGatewayApplicationUpstreams[] | cdktf.IResolvable;
}
export interface BeyondcorpSecurityGatewayApplicationEndpointMatchers {
    /**
    * Required. Hostname of the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#hostname BeyondcorpSecurityGatewayApplication#hostname}
    */
    readonly hostname: string;
    /**
    * Optional. Ports of the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#ports BeyondcorpSecurityGatewayApplication#ports}
    */
    readonly ports?: number[];
}
export declare function beyondcorpSecurityGatewayApplicationEndpointMatchersToTerraform(struct?: BeyondcorpSecurityGatewayApplicationEndpointMatchers | cdktf.IResolvable): any;
export declare function beyondcorpSecurityGatewayApplicationEndpointMatchersToHclTerraform(struct?: BeyondcorpSecurityGatewayApplicationEndpointMatchers | cdktf.IResolvable): any;
export declare class BeyondcorpSecurityGatewayApplicationEndpointMatchersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): BeyondcorpSecurityGatewayApplicationEndpointMatchers | cdktf.IResolvable | undefined;
    set internalValue(value: BeyondcorpSecurityGatewayApplicationEndpointMatchers | cdktf.IResolvable | undefined);
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    get hostnameInput(): string | undefined;
    private _ports?;
    get ports(): number[];
    set ports(value: number[]);
    resetPorts(): void;
    get portsInput(): number[] | undefined;
}
export declare class BeyondcorpSecurityGatewayApplicationEndpointMatchersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: BeyondcorpSecurityGatewayApplicationEndpointMatchers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): BeyondcorpSecurityGatewayApplicationEndpointMatchersOutputReference;
}
export interface BeyondcorpSecurityGatewayApplicationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#create BeyondcorpSecurityGatewayApplication#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#delete BeyondcorpSecurityGatewayApplication#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#update BeyondcorpSecurityGatewayApplication#update}
    */
    readonly update?: string;
}
export declare function beyondcorpSecurityGatewayApplicationTimeoutsToTerraform(struct?: BeyondcorpSecurityGatewayApplicationTimeouts | cdktf.IResolvable): any;
export declare function beyondcorpSecurityGatewayApplicationTimeoutsToHclTerraform(struct?: BeyondcorpSecurityGatewayApplicationTimeouts | cdktf.IResolvable): any;
export declare class BeyondcorpSecurityGatewayApplicationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): BeyondcorpSecurityGatewayApplicationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: BeyondcorpSecurityGatewayApplicationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicy {
    /**
    * Required. List of regions where the application sends traffic to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#regions BeyondcorpSecurityGatewayApplication#regions}
    */
    readonly regions: string[];
}
export declare function beyondcorpSecurityGatewayApplicationUpstreamsEgressPolicyToTerraform(struct?: BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicyOutputReference | BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicy): any;
export declare function beyondcorpSecurityGatewayApplicationUpstreamsEgressPolicyToHclTerraform(struct?: BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicyOutputReference | BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicy): any;
export declare class BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicy | undefined;
    set internalValue(value: BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicy | undefined);
    private _regions?;
    get regions(): string[];
    set regions(value: string[]);
    get regionsInput(): string[] | undefined;
}
export interface BeyondcorpSecurityGatewayApplicationUpstreamsNetwork {
    /**
    * Required. Network name is of the format:
    * 'projects/{project}/global/networks/{network}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#name BeyondcorpSecurityGatewayApplication#name}
    */
    readonly name: string;
}
export declare function beyondcorpSecurityGatewayApplicationUpstreamsNetworkToTerraform(struct?: BeyondcorpSecurityGatewayApplicationUpstreamsNetworkOutputReference | BeyondcorpSecurityGatewayApplicationUpstreamsNetwork): any;
export declare function beyondcorpSecurityGatewayApplicationUpstreamsNetworkToHclTerraform(struct?: BeyondcorpSecurityGatewayApplicationUpstreamsNetworkOutputReference | BeyondcorpSecurityGatewayApplicationUpstreamsNetwork): any;
export declare class BeyondcorpSecurityGatewayApplicationUpstreamsNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): BeyondcorpSecurityGatewayApplicationUpstreamsNetwork | undefined;
    set internalValue(value: BeyondcorpSecurityGatewayApplicationUpstreamsNetwork | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export interface BeyondcorpSecurityGatewayApplicationUpstreams {
    /**
    * egress_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#egress_policy BeyondcorpSecurityGatewayApplication#egress_policy}
    */
    readonly egressPolicy?: BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicy;
    /**
    * network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#network BeyondcorpSecurityGatewayApplication#network}
    */
    readonly network?: BeyondcorpSecurityGatewayApplicationUpstreamsNetwork;
}
export declare function beyondcorpSecurityGatewayApplicationUpstreamsToTerraform(struct?: BeyondcorpSecurityGatewayApplicationUpstreams | cdktf.IResolvable): any;
export declare function beyondcorpSecurityGatewayApplicationUpstreamsToHclTerraform(struct?: BeyondcorpSecurityGatewayApplicationUpstreams | cdktf.IResolvable): any;
export declare class BeyondcorpSecurityGatewayApplicationUpstreamsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): BeyondcorpSecurityGatewayApplicationUpstreams | cdktf.IResolvable | undefined;
    set internalValue(value: BeyondcorpSecurityGatewayApplicationUpstreams | cdktf.IResolvable | undefined);
    private _egressPolicy;
    get egressPolicy(): BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicyOutputReference;
    putEgressPolicy(value: BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicy): void;
    resetEgressPolicy(): void;
    get egressPolicyInput(): BeyondcorpSecurityGatewayApplicationUpstreamsEgressPolicy | undefined;
    private _network;
    get network(): BeyondcorpSecurityGatewayApplicationUpstreamsNetworkOutputReference;
    putNetwork(value: BeyondcorpSecurityGatewayApplicationUpstreamsNetwork): void;
    resetNetwork(): void;
    get networkInput(): BeyondcorpSecurityGatewayApplicationUpstreamsNetwork | undefined;
}
export declare class BeyondcorpSecurityGatewayApplicationUpstreamsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: BeyondcorpSecurityGatewayApplicationUpstreams[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): BeyondcorpSecurityGatewayApplicationUpstreamsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application google_beyondcorp_security_gateway_application}
*/
export declare class BeyondcorpSecurityGatewayApplication extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_beyondcorp_security_gateway_application";
    /**
    * Generates CDKTF code for importing a BeyondcorpSecurityGatewayApplication resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the BeyondcorpSecurityGatewayApplication to import
    * @param importFromId The id of the existing BeyondcorpSecurityGatewayApplication that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the BeyondcorpSecurityGatewayApplication to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.37.0/docs/resources/beyondcorp_security_gateway_application google_beyondcorp_security_gateway_application} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options BeyondcorpSecurityGatewayApplicationConfig
    */
    constructor(scope: Construct, id: string, config: BeyondcorpSecurityGatewayApplicationConfig);
    private _applicationId?;
    get applicationId(): string;
    set applicationId(value: string);
    get applicationIdInput(): string | undefined;
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _securityGatewayId?;
    get securityGatewayId(): string;
    set securityGatewayId(value: string);
    get securityGatewayIdInput(): string | undefined;
    get updateTime(): string;
    private _endpointMatchers;
    get endpointMatchers(): BeyondcorpSecurityGatewayApplicationEndpointMatchersList;
    putEndpointMatchers(value: BeyondcorpSecurityGatewayApplicationEndpointMatchers[] | cdktf.IResolvable): void;
    get endpointMatchersInput(): cdktf.IResolvable | BeyondcorpSecurityGatewayApplicationEndpointMatchers[] | undefined;
    private _timeouts;
    get timeouts(): BeyondcorpSecurityGatewayApplicationTimeoutsOutputReference;
    putTimeouts(value: BeyondcorpSecurityGatewayApplicationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | BeyondcorpSecurityGatewayApplicationTimeouts | undefined;
    private _upstreams;
    get upstreams(): BeyondcorpSecurityGatewayApplicationUpstreamsList;
    putUpstreams(value: BeyondcorpSecurityGatewayApplicationUpstreams[] | cdktf.IResolvable): void;
    resetUpstreams(): void;
    get upstreamsInput(): cdktf.IResolvable | BeyondcorpSecurityGatewayApplicationUpstreams[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
